<?php
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Factory\AppFactory;
use Slim\Views\Twig;
use Slim\Views\TwigMiddleware;
use DI\Container;
use Slim\Routing\RouteContext;
use Slim\Routing\RouteCollectorProxy;
use Psr\Http\Server\RequestHandlerInterface;
use Psr\Http\Message\UploadedFileInterface;

require __DIR__ . '/vendor/autoload.php';

$container = new Container();
AppFactory::setContainer($container);

$app = AppFactory::create();

$app->addBodyParsingMiddleware();
$app->addRoutingMiddleware();
$app->add(new Slim\Middleware\MethodOverrideMiddleware);

$twig = Twig::create('./templates', ['cache' => false]);
$app->add(TwigMiddleware::create($app, $twig));


$errorMiddleware = $app->addErrorMiddleware(true, true, true);

$app->get('/ui/', function (Request $request, Response $response, $args) {
    $view = Twig::fromRequest($request);
    return $view->render($response, 'index.html',
			 []);
});

$app->group('/ui/user', function (RouteCollectorProxy $group){
    $group->get('',              'App\Modules\User:all_user');
    $group->get('/new',          'App\Modules\User:new_user');
    $group->get('/{userid}',     'App\Modules\User:edit_user');
    $group->delete('/{userid}',  'App\Modules\User:delete_user');
    $group->post('/new',         'App\Modules\User:create_user');
    $group->post('/{userid}',    'App\Modules\User:update_user'); 
});

$app->group('/ui/translate', function (RouteCollectorProxy $group){
    $group->get('',              'App\Modules\Translate:all_dialplan');
    $group->get('/new',          'App\Modules\Translate:new_dialplan');
    $group->get('/{id}',     'App\Modules\Translate:edit_dialplan');
    $group->delete('/{id}',  'App\Modules\Translate:delete_dialplan');
    $group->post('/new',         'App\Modules\Translate:create_dialplan');
    $group->post('/{id}',    'App\Modules\Translate:update_dialplan'); 
});

$app->group('/ui/update', function (RouteCollectorProxy $group){
    $group->get('',     'App\Modules\Update:show');
    $group->post('',    'App\Modules\Update:load_image'); 
    $group->post('/image',  'App\Modules\Update:update_image');
});


$app->get('/ui/rules', function (Request $request, Response $response, $args) {

    $view = Twig::fromRequest($request);
    $db = new SQLite3("private/dbtext");
    $q = "SELECT t.id, t.lcr_id, g.gw_name, r.prefix, r.from_uri, r.request_uri, t.priority, t.weight from lcr_rule_target as t left join lcr_gw as g on  g.id == t.gw_id left join lcr_rule as r on t.rule_id == r.id";
    $result = $db->query($q);

    $rules = [];
    while ($row = $result->fetchArray()){
	$rule = [];
	$rule['id'] = $row['id'];
	$rule['lcr_id'] = $row['lcr_id'];
	$rule['gw_name'] = $row['gw_name'];
	$rule['prefix'] = $row['prefix'];
	$rule['from_uri'] = $row['from_uri'];
	$rule['request_uri'] = $row['request_uri'];
	$rule['priority'] = $row['priority'];
	$rule['weight'] = $row['weight'];
	$rules[] = $rule;
    }

    $q1 = 'SELECT * from lcr_rule';
    $result1 = $db->query($q1);
    
    $ruless = [];
    while ($row = $result1->fetchArray()) {
	$rule = [];
	$rule['id'] = $row['id'];
	$rule['lcr_id'] = $row['lcr_id'];
	$rule['prefix'] = $row['prefix'];
	$rule['from_uri'] = $row['from_uri'];
	$rule['request_uri'] = $row['request_uri'];
	$rule['mt_tvalue'] = $row['mt_tvalue'];
	$rule['stopper'] = $row['stopper'];
	$rule['enabled'] = $row['enabled'];
	$ruless[] = $rule;
    }

    $db->close();
    
    return $view->render($response, 'rules.html',
			 [ 'rules' => $rules,
			   'ruless' => $ruless]);
});

$app->get('/ui/gws', function (Request $request, Response $response, $args) {

    $view = Twig::fromRequest($request);
    $db = new SQLite3("private/dbtext");
    $q = 'SELECT * from lcr_gw';
    $result = $db->query($q);

    $gwss = [];
    while ($row = $result->fetchArray()) {
	$gw = [];
	$gw['id'] = $row['id'];
	$gw['lcr_id'] = $row['lcr_id'];
	$gw['name'] = $row['gw_name'];
	$gw['ip_addr'] = $row['ip_addr'];
	$gw['hostname'] = $row['hostname'];
	$gw['port'] = $row['port'];
	$gw['params'] = $row['params'];
	$gw['scheme'] = $row['uri_scheme'];
	$gw['transport'] = $row['transport'];
	$gw['strip'] = $row['strip'];
	$gw['prefix'] = $row['prefix'];
	$gw['tag'] = $row['tag'];
	$gw['flags'] = $row['flags'];
	$gw['defunct'] = $row['defunct'];
	$gwss[] = $gw;
    }

    /* echo var_dump($ruless); */
    $db->close();
    
    return $view->render($response, 'gws.html',
			 [ 'gws' => $gwss]);
});


$app->get('/ui/logic', function (Request $request, Response $response, $args) {

    $view = Twig::fromRequest($request);
    $filename = "/persist/etc/kamailio/route_logic.cfg";
    $route_logic = fopen($filename, "r") or die("Unable to open file!");
    $data = fread($route_logic, filesize($filename));

    
    fclose($route_logic);
    
    return $view->render($response, 'logic.html',
			 [ 'logic' => $data,
			   'rules' => $ruless]);
});


$app->get('/ui/cdr', function (Request $request, Response $response, $args) {

    $view = Twig::fromRequest($request);
    $db = new SQLite3("/persist/etc/kamailio/dbtext");
    $q = 'SELECT id, method, callid, sip_code, sip_reason,
datetime(time) as time, src_user, src_domain, src_ip, dst_ouser, dst_user, dst_domain from acc
order by time DESC';
    $result = $db->query($q);
    /* date_default_timezone_set("Europe/Minsk"); */
    
    $calls = [];
    while ($row = $result->fetchArray()) {
	$call = [];
	$call['id'] = $row['id'];
	$call['method'] = $row['method'];
	$call['callid'] = $row['callid'];
	$call['sip_code'] = $row['sip_code'];
	$call['sip_reason'] = $row['sip_reason'];
	$date = new DateTime($row['time']);
	$date->setTimezone(new DateTimezone("Europe/Minsk"));
	$day = $date->format("d-m-Y");
	$call['time'] = $date->format("H-i-s");
	$call['src_user'] = $row['src_user'];
	$call['src_domain'] = $row['src_domain'];
	$call['src_ip'] = $row['src_ip'];
	$call['dst_ouser'] = $row['dst_ouser'];
	$call['dst_user'] = $row['dst_user'];
	$call['dst_domain'] = $row['dst_domain'];
	$calls[$day][] = $call;
    } 

    $q = 'SELECT id, method, callid, sip_code, sip_reason,
datetime(time) as time, src_user, src_domain, src_ip, dst_ouser, dst_user, dst_domain from missed_calls
    order by time DESC';
    $result = $db->query($q);

    $missed = [];
    while ($row = $result->fetchArray()) {
	$call = [];
	$call['id'] = $row['id'];
	$call['method'] = $row['method'];
	$call['callid'] = $row['callid'];
	$call['sip_code'] = $row['sip_code'];
	$call['sip_reason'] = $row['sip_reason'];
	$date = new DateTime($row['time']);
	$date->setTimezone(new DateTimezone("Europe/Minsk"));
	$day = $date->format("d-m-Y");
	$call['time'] = $date->format("H-i-s");
	$call['src_user'] = $row['src_user'];
	$call['src_domain'] = $row['src_domain'];
	$call['src_ip'] = $row['src_ip'];
	$call['dst_ouser'] = $row['dst_ouser'];
	$call['dst_user'] = $row['dst_user'];
	$call['dst_domain'] = $row['dst_domain'];
	$missed[$day][] = $call;
    } 
    $db->close();
    
    return $view->render($response, 'cdr.html',
			 [ 'calls' => $calls,
			   'missed' => $missed]);
});

$app->get('/ui/call/{callid}', function (Request $request, Response $response, $args) {

    $view = Twig::fromRequest($request);
    $db = new SQLite3("/persist/etc/kamailio/dbtext");
    $q = 'SELECT id, method, callid, sip_code, sip_reason,
datetime(time) as time, src_user, src_domain, src_ip, dst_ouser, dst_user, dst_domain from acc
where callid =="'. $args['callid'] . '"';
    $result = $db->query($q);
    /* date_default_timezone_set("Europe/Minsk"); */
    
    $calls = [];
    while ($row = $result->fetchArray()) {
	$call = [];
	$call['id'] = $row['id'];
	$call['method'] = $row['method'];
	$call['callid'] = $row['callid'];
	$call['sip_code'] = $row['sip_code'];
	$call['sip_reason'] = $row['sip_reason'];
	$date = new DateTime($row['time']);
	$date->setTimezone(new DateTimezone("Europe/Minsk"));
	$day = $date->format("d-m-Y");
	$call['time'] = $date->format("H-i-s");
	$call['src_user'] = $row['src_user'];
	$call['src_domain'] = $row['src_domain'];
	$call['src_ip'] = $row['src_ip'];
	$call['dst_ouser'] = $row['dst_ouser'];
	$call['dst_user'] = $row['dst_user'];
	$call['dst_domain'] = $row['dst_domain'];
	$calls['date'][] = $call;
    } 

    $q = 'SELECT id, method, callid, sip_code, sip_reason,
    datetime(time) as time, src_user, src_domain, src_ip, dst_ouser, dst_user, dst_domain from missed_calls
    where callid =="'. $args['callid'] . '"';
    $result = $db->query($q);

    $missed = [];
    while ($row = $result->fetchArray()) {
	$call = [];
	$call['id'] = $row['id'];
	$call['method'] = $row['method'];
	$call['callid'] = $row['callid'];
	$call['sip_code'] = $row['sip_code'];
	$call['sip_reason'] = $row['sip_reason'];
	$date = new DateTime($row['time']);
	$date->setTimezone(new DateTimezone("Europe/Minsk"));
	$day = $date->format("d-m-Y");
	$call['time'] = $date->format("H-i-s");
	$call['src_user'] = $row['src_user'];
	$call['src_domain'] = $row['src_domain'];
	$call['src_ip'] = $row['src_ip'];
	$call['dst_ouser'] = $row['dst_ouser'];
	$call['dst_user'] = $row['dst_user'];
	$call['dst_domain'] = $row['dst_domain'];
	$missed[$date][] = $call;
    } 
    $db->close();
    
    return $view->render($response, 'cdr.html',
			 [ 'calls' => $calls,
			   'missed' => $missed]);
});


$app->get('/ui/translate_old', function (Request $request, Response $response, $args) {

    $view = Twig::fromRequest($request);
    $db = new SQLite3("private/dbtext");
    $q = 'SELECT * from dialplan';
    $result = $db->query($q);

    $trs = [];
    while ($row = $result->fetchArray()) {
	$tr = [];
	$tr['id'] = $row['id'];
	$tr['dpid'] = $row['dpid'];
	$tr['pr'] = $row['pr'];
	$tr['match_op'] = $row['match_op'];
	$tr['match_exp'] = $row['match_exp'];
	$tr['match_len'] = $row['match_len'];
	$tr['subst_exp'] = $row['subst_exp'];
	$tr['repl_exp'] = $row['repl_exp'];
	$tr['attrs'] = $row['attrs'];
	$trs[] = $tr;
    }

    /* echo var_dump($ruless); */
    $db->close();
    
    return $view->render($response, 'translate.html',
			 [ 'translate' => $trs]);
});

// Update section


// Run app
$app->run();

