<?php

namespace App\Components;

use App\Model\Dialplan;
use SQLite3;
use SQLite3Exception;
use Exception;

class DialplanStorage extends Storage
{

    public function __construct($filename)
    {
	parent::__construct($filename);
    }


    public function get_dialplans()
    {
	$this->setQuery('SELECT * from dialplan');
	$result = $this->query();
	$dials = [];
	foreach($result as $d)
	{
	    $dial = Dialplan::from_array($d);
	    $dials[] = $dial;
	}
	return $dials;
    }

    public function get_dialplan($id)
    {
	$this->setQuery("SELECT * from dialplan where id=:id");
	$this->bindValues([[':id', $id, SQLITE3_INTEGER]]);
	$result = $this->query();
	$dials = [];
	foreach($result as $d)
	{
	    $dial = Dialplan::from_array($d);
	    $dials = $dial;
	}
	return $dials;
    }


    public function search_by_class($id)
    {
	$this->setQuery("SELECT * from dialplan where dpid=:id");
	$this->bindValues([[':id', $id, SQLITE3_INTEGER]]);
	$result = $this->query();
	$dials = [];
	foreach($result as $d)
	{
	    $dial = Dialplan::from_array($d);
	    $dials[] = $dial;
	}
	return $dials;
    }

    public function delete_dialplan($id)
    {
	$this->setQuery("DELETE from dialplan where id=:id");
	$this->bindValues([[':id', $id, SQLITE3_INTEGER]]);
	$result = $this->query();
	return $result;
    }

    public function insert_dialplan($d){
	$temp = "INSERT INTO dialplan (dpid, pr, match_op, match_exp, match_len, subst_exp, repl_exp, attrs)";
	$temp .= "VALUES(:dpid, :pr, :match_op, :match_exp, :match_len, :subst_exp, :repl_exp, :attrs)";
	$this->setQuery($temp);
	$this->bindValues([[':dpid', $d->dpid, SQLITE3_INTEGER],
			   [':pr', $d->pr, SQLITE3_INTEGER],
			   [':match_op', $d->match_op, SQLITE3_INTEGER],
			   [':match_exp', $d->match_exp, SQLITE3_TEXT],
			   [':match_len', $d->match_len, SQLITE3_TEXT],
			   [':subst_exp', $d->subst_exp, SQLITE3_TEXT],
			   [':repl_exp', $d->repl_exp, SQLITE3_TEXT],
			   [':attrs', $d->attrs, SQLITE3_TEXT]]);
	$result = $this->query();
	return $result;
    }

    public function update_dialplan($d){
	$temp = "UPDATE dialplan SET ";
	$temp .= "dpid=:dpid, ";
	$temp .= "pr=:pr, ";
	$temp .= "match_op=:match_op, ";
	$temp .= "match_exp=:match_exp, ";
	$temp .= "match_len=:match_len, ";
	$temp .= "subst_exp=:subst_exp, ";
	$temp .= "repl_exp=:repl_exp, ";
	$temp .= "attrs=:attrs ";
	$temp .= "WHERE	id = :id;";
	$this->setQuery($temp);
	$this->bindValues([[':dpid', $d->dpid, SQLITE3_INTEGER],
			   [':id', $d->id, SQLITE3_INTEGER],
			   [':pr', $d->pr, SQLITE3_INTEGER],
			   [':match_op', $d->match_op, SQLITE3_INTEGER],
			   [':match_exp', $d->match_exp, SQLITE3_TEXT],
			   [':match_len', $d->match_len, SQLITE3_TEXT],
			   [':subst_exp', $d->subst_exp, SQLITE3_TEXT],
			   [':repl_exp', $d->repl_exp, SQLITE3_TEXT],
			   [':attrs', $d->attrs, SQLITE3_TEXT]]);
	$result = $this->query();
	return $result;
    }

}
