<?php

namespace App\Components;

use App\Model\Subscriber;
use SQLite3;
use SQLite3Exception;
use Exception;

class Storage
{
    protected $db;
    protected $file;
    private $query;
    private $values;

    public function __construct($filename)
    {
	$this->file = $filename;
	$this->db = new SQLite3($filename);
    }

    public function __destructor()
    {
	$this->db->close();
    }

    protected function setQuery(string $query)
    {
	$this->query = $this->db->prepare($query);
	if($this->db->lastErrorCode()){
	    throw new Exception($this->db->lastErrorMsg());
	}
    }
    
    
    protected function bindValues(array $values)
    {
	if ($values){
	    foreach($values as $val){
		$this->query->bindValue($val[0], $val[1], $val[2]);
		if($this->db->lastErrorCode()){
		    throw new Exception($this->db->lastErrorMsg());
		}
	    }
	}
    }
    
    protected function query()
    {
	$result = $this->query->execute();
	if($this->db->lastErrorCode()){
	    throw new Exception($this->db->lastErrorMsg());
	} else {
	    $rows = [];
	    while ($row = $result->fetchArray())
	    {
		$rows[] = $row;
	    }
	    return $rows;
	}
    }

}
