<?php

namespace App\Modules;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Container\ContainerInterface;
use App\Model\Dialplan;
use App\Components\DialplanStorage;

class Translate extends BaseHandler
{

    private $storage;
    
    public function __construct(ContainerInterface $container)
    {
	$this->storage = new DialplanStorage("private/dbtext");
	parent::__construct();
    }
    
    public function all_dialplan(ServerRequestInterface $request,
				 ResponseInterface $response, array $args): ResponseInterface
    {
	$this->prepare($request, $response);
	$dialplan = Dialplan::all($this->storage);
	return $this->render('translate.html',
			     [ 'dialplan' => $dialplan]);
    }

    public function new_dialplan(ServerRequestInterface $request,
				 ResponseInterface $response, array $args): ResponseInterface
    {
	$this->prepare($request, $response);
	$dialplan = new Dialplan();
	return $this->render('edit_translate.html',
			     [ 'dialplan' => $dialplan]);
    }

    public function edit_dialplan(ServerRequestInterface $request,
				  ResponseInterface $response, array $args): ResponseInterface
    {
	$this->prepare($request, $response);
	$dialplanid = $args['id'];
	$dialplan = new Dialplan();
	$dialplan->id = $dialplanid;
	$dialplan->storage($this->storage);
	$d = $dialplan->read();
	return $this->render('edit_translate.html',
			     [ 'dialplan' => $d]);
    }

    public function create_dialplan(ServerRequestInterface $request,
				    ResponseInterface $response,
				    array $args): ResponseInterface
    {
	$this->prepare($request, $response);
	$dialplanid = "new";
	$data = $request->getParsedBody();
	$dialplan = Dialplan::from_array($data);
	$dialplan->storage($this->storage);
	if(isset($data['save']))
	{
	    $dialplan->save();
	}
	return $this->redirect("/ui/translate");
    }

    public function update_dialplan(ServerRequestInterface $request,
				    ResponseInterface $response,
				    array $args): ResponseInterface
    {
	$this->prepare($request, $response);
	$dialplanid = $args['id'];
	$data = $request->getParsedBody();
	$data['id'] = intval($dialplanid);
	$dialplan = Dialplan::from_array($data);
	/* echo var_dump($data); */
	$dialplan->storage($this->storage);
	if(isset($data['save']))
	{
	    $dialplan->save();
	}
	return $this->redirect("/ui/translate");
    }

    public function delete_dialplan(ServerRequestInterface $request,
				    ResponseInterface $response,
				    array $args): ResponseInterface
    {
	$this->prepare($request, $response);
	$dialplanid = $args['id'];
	$dialplan = new Dialplan();
	$dialplan->id = $dialplanid;
	$dialplan->storage($this->storage);
	$dialplan->remove();
	return $this->redirect("/ui/translate");
    }
}
